@@ -469,3 +469,119 @@ def test_issue_72_nonexistent_file_error():
     res.resolve_references()
 
   assert 'not/exist' in str(exinfo.value)
+
+
+
+@pytest.mark.skipif(none_of('openapi-spec-validator'), reason='Missing backends')
+def test_issue_78_resolve_internal_bug():
+  specs = ''
+  with open('tests/specs/issue_78/openapi.json', 'r') as fh:
+    specs = fh.read()
+
+  from prance.util import formats
+  specs = formats.parse_spec(specs, 'openapi.json')
+
+  res = resolver.RefResolver(specs,
+      fs.abspath('openapi.json'),
+      resolve_types = resolver.RESOLVE_FILES
+      )
+  res.resolve_references()
+
+  from prance.util.path import path_get
+  val = path_get(res.specs, ('paths', '/endpoint', 'post', 'requestBody', 'content'))
+
+  # Reference to file is resolved
+  assert 'application/json' in val
+  # Internal reference within file is NOT resolved
+  assert '$ref' in val['application/json']
+
+
+
+@pytest.mark.skipif(none_of('openapi-spec-validator'), reason='Missing backends')
+def test_issue_77_translate_external():
+  specs = ''
+  with open('tests/specs/issue_78/openapi.json', 'r') as fh:
+    specs = fh.read()
+
+  from prance.util import formats
+  specs = formats.parse_spec(specs, 'openapi.json')
+
+  res = resolver.RefResolver(specs,
+      fs.abspath('openapi.json'),
+      resolve_types = resolver.RESOLVE_FILES,
+      resolve_method= resolver.TRANSLATE_EXTERNAL
+      )
+  res.resolve_references()
+
+  from prance.util.path import path_get
+  val = path_get(res.specs, ('components', 'schemas', '_schemas.json_Body'))
+
+  # Reference to file is translated in components/schemas
+  assert 'content' in val
+  assert 'application/json' in val['content']
+
+  # Reference url is updated
+  val = path_get(res.specs, ('paths', '/endpoint', 'post', 'requestBody', '$ref'))
+  assert val == '#/components/schemas/_schemas.json_Body'
+
+
+
+@pytest.mark.skipif(none_of('openapi-spec-validator'), reason='Missing backends')
+def test_issue_77_translate_external_refs_internal():
+  specs = ''
+  with open('tests/specs/issue_78/openapi.json', 'r') as fh:
+    specs = fh.read()
+
+  from prance.util import formats
+  specs = formats.parse_spec(specs, 'openapi.json')
+
+  res = resolver.RefResolver(specs,
+      fs.abspath('openapi.json'),
+      resolve_types = resolver.RESOLVE_FILES | resolver.RESOLVE_INTERNAL,
+      resolve_method= resolver.TRANSLATE_EXTERNAL
+      )
+  res.resolve_references()
+
+  from prance.util.path import path_get
+  val = path_get(res.specs, ('components', 'schemas', '_schemas.json_Body'))
+
+  # Reference to file is translated in components/schemas
+  assert 'content' in val
+  assert 'application/json' in val['content']
+
+  # Internal Reference links updated
+  assert '#/components/schemas/_schemas.json_Something' == val['content']['application/json']['$ref']
+
+  # Internal references is copied to componnents/schemas seperately
+  val = path_get(res.specs, ('components', 'schemas', '_schemas.json_Something'))
+  assert 'type' in val
+
+  # File reference url is updated as well
+  val = path_get(res.specs, ('paths', '/endpoint', 'post', 'requestBody', '$ref'))
+  assert val == '#/components/schemas/_schemas.json_Body'
+
+
+@pytest.mark.skipif(none_of('openapi-spec-validator'), reason='Missing backends')
+def test_issue_77_internal_refs_unresolved():
+  specs = ''
+  with open('tests/specs/issue_78/openapi.json', 'r') as fh:
+    specs = fh.read()
+
+  from prance.util import formats
+  specs = formats.parse_spec(specs, 'openapi.json')
+
+  res = resolver.RefResolver(specs,
+      fs.abspath('openapi.json'),
+      resolve_types = resolver.RESOLVE_FILES,
+      resolve_method= resolver.TRANSLATE_EXTERNAL
+      )
+  res.resolve_references()
+
+  from prance.util.path import path_get
+  val = path_get(res.specs, ('components', 'schemas'))
+
+  # File reference resolved
+  assert '_schemas.json_Body' in val
+
+  # Internal file reference not resolved
+  assert '_schemas.json_Something' not in val
